==> tinyerp-server_3.1.99+3.2.0rc1.orig.tar.gz: tinyerp-server-3.2.0/bin/addons/base/module/wizard/wizard_module_upgrade.py <==
# -*- coding: iso-8859-1 -*-
##############################################################################
#
# Copyright (c) 2004 TINY SPRL. (http://tiny.be) All Rights Reserved.
#                    Fabien Pinckaers <fp@tiny.Be>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard
import netsvc

class wizard_info_get(wizard.interface):
	def _upgrade_module(self, uid, datas):
		raise wizard.except_wizard('UserError', 'To apply modules installation and upgrades,\nYou have to start the Tiny ERP server with:\n\ttinyerp-server.py --upgrade')
	states = {
		'init': {
			'actions': [_upgrade_module], 
			'result': {'type':'state', 'state':'end'}
		},
	}
wizard_info_get('module.upgrade')

==> tinyerp-server_3.4.2.orig.tar.gz: tinyerp-server-3.4.2/bin/addons/base/module/wizard/wizard_module_upgrade.py <==
# -*- coding: iso-8859-1 -*-
##############################################################################
#
# Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#                    Fabien Pinckaers <fp@tiny.Be>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard

class wizard_info_get(wizard.interface):
	def _upgrade_module(self, cr, uid, data, context):
		raise wizard.except_wizard('UserError', 'To apply modules installation and upgrades,\nYou have to start the Tiny ERP server with:\n\ttinyerp-server.py --upgrade')
		
	states = {
		'init': {
			'actions': [_upgrade_module], 
			'result': {'type':'state', 'state':'end'}
		},
	}
wizard_info_get('module.upgrade')
